# Getting Started

## Installation instructions

To install `caterpillard` package from PyPI:

```console
(env) $ pip install caterpillard
```

## Compatibility

This package has been tested on Python 3.9 and Python 3.10 across all major operating
systems like `Linux`, `MacOs` and `Windows`.

## Usage guide

The detailed {doc}`tutorial </notebooks/tutorial>` section of the documentation provides a
complete walkthrough of the package with all the available methods and capabilities.

## Implementation details

A detailed source code definitions are available at {doc}`Source Code
<source_code_details>` page.

## Cite this package


If you utilize this package then please use the bibliography in IEEE format to cite this
package and the associated Journal article in your work:

> [1] Prabal Pratap Singh and Deepu Philip, “Caterpillar Diagram.” Jan. 12, 2023.
> Accessed: Jan. 12, 2023. [Online]. Available:
> https://github.com/mechaprabal/caterpillard

> [2] P. P. Singh and D. Philip, “An innovative color-coding scheme for terrorism threat
> advisory system,” Methodological Innovations, p. 20597991221144576, Dec. 2022, doi:
> 10.1177/20597991221144577.

